library(ggplot2)

#######################################

tbls1 <- c(
           "sum.ro.06.txt",
           "sum.ro.07.txt"
          )
tbls2 <- c(
           "thread-pool",
           "thread-per-connection"
          )

titler="OLTP (ro), MariaDB-5.5.21, 16 cores"
filename="graph.tp4.pdf"

pairs <- data.frame(tbls1, tbls2)

dvf<-data.frame()
for (tb in tbls1) {
td1<-read.csv(tb, sep=" ",header=F)
dv.ver=as.data.frame(td1)
dv.ver$engine=pairs[which(pairs$tbls1  == tb),]$tbls2
dvf=rbind(dvf,dv.ver)
}

colnames(dvf) <- c("Threads", "sec", "Thrp", "Resp","Inst")

filtersec <- function(x) { subset(x, sec>30)  }

dsum <- ddply(filtersec(dvf), c("Inst","Threads", "sec"),
              summarize,
              Thrp = sum(Thrp), Resp = max(Resp),
              Threads = sum(Threads)
              )

q90 <- function(x) { quantile(x, probs = c(0.90)) }
q50 <- function(x) { quantile(x, probs = c(0.50)) }

d1 <- ddply(filtersec(dsum),
            c("Inst","Threads"),
            summarize,
            Thrp50 = round(as.numeric(q50(Thrp))),
            Resp90 = round(as.numeric(max(Resp)), 3)
          )

d1

#pdf(file=filename,paper="A4",width=10, height=8)
png(file="threadpool.png", w=640, h=500)

m <- ggplot(filtersec(dsum),
            aes(x = factor(Threads), Thrp,
                color=factor(Inst),group=factor(Inst)))

m + geom_jitter(size=1.5, alpha=0.85) +
  opts(title = paste("sysbench, ",titler)) +
  xlab("Threads") +
  ylab("Throughput, tps") + ylim(0,max(dsum$Thrp))+
  opts(legend.position = "bottom") + opts(legend.direction = "horizontal")+scale_colour_discrete(name="") +
  stat_summary(fun.y = "q50",
               fun.ymin = "q50", fun.ymax = "q50",
               geom = "crossbar",size = 1/4,legend = FALSE) +
  geom_text(data = d1, aes(x = factor(Threads), y = Thrp50, vjust = 3.5 - 2*as.integer(factor(Inst)), label = Thrp50), size=4, color="black", legend = FALSE) 

